# PyRandyOS

Library of common functions for Python applications

[![GitHub Badge](https://img.shields.io/badge/GitHub-181717?logo=github&logoColor=fff&style=plastic)](https://github.com/emanspeaks/pyrandyos)
[![CI Status](https://github.com/emanspeaks/pyrandyos/actions/workflows/ci.yml/badge.svg)](https://github.com/emanspeaks/pyrandyos/actions)
[![last-commit](https://img.shields.io/github/last-commit/emanspeaks/pyrandyos)](https://github.com/emanspeaks/pyrandyos/commits/main)
[![PyPI Downloads](https://img.shields.io/pypi/dm/pyrandyos?label=PyPI%20downloads)](https://pypi.org/project/pyrandyos/)
<!-- [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pyrandyos?label=Conda%20downloads)](https://anaconda.org/conda-forge/pyrandyos) -->

## Licenses

### Icons

This repo uses icons taken from other open source icon libraries.  Links to their licensing info are maintained alongside the URLs for the icon fonts in [`pyrandyos/gui/icons/iconfont/sources.py`](pyrandyos/gui/icons/iconfont/sources.py), where the paths to the license files are with respect to the repo root at the given URL.
